@@ -5,15 +5,14 @@
 
 #pragma once
 
-#include <sstream>
 #include <iomanip>
 #include <locale>
+#include <sstream>
 
-namespace utils
-{
+namespace utils {
 
 template<typename T>
-inline std::string format(const T& value)
+inline std::string format(const T &value)
 {
     static std::locale loc("");
     std::stringstream ss;
@@ -23,7 +22,7 @@ inline std::string format(const T& value)
 }
 
 template<>
-inline std::string format(const double & value)
+inline std::string format(const double &value)
 {
     static std::locale loc("");
     std::stringstream ss;
@@ -32,4 +31,4 @@ inline std::string format(const double & value)
     return ss.str();
 }
 
-}
+} // namespace utils
