@@ -1,5 +1,5 @@
 //
-// Copyright(c) 2016 Gabi Melman.
+// Copyright(c) 2016-2018 Gabi Melman.
 // Distributed under the MIT License (http://opensource.org/licenses/MIT)
 //
 
@@ -11,23 +11,15 @@
 //
 
 #if !defined(SPDLOG_FMT_EXTERNAL)
-
 #ifndef FMT_HEADER_ONLY
 #define FMT_HEADER_ONLY
 #endif
 #ifndef FMT_USE_WINDOWS_H
 #define FMT_USE_WINDOWS_H 0
 #endif
+#include "bundled/core.h"
 #include "bundled/format.h"
-#if defined(SPDLOG_FMT_PRINTF)
-#include "bundled/printf.h"
-#endif
-
 #else // external fmtlib
-
+#include <fmt/core.h>
 #include <fmt/format.h>
-#if defined(SPDLOG_FMT_PRINTF)
-#include <fmt/printf.h>
-#endif
-
 #endif
