@@ -4,8 +4,13 @@
 
 #include "includes.h"
 
+#if SPDLOG_ACTIVE_LEVEL != SPDLOG_LEVEL_DEBUG
+#error "Invalid SPDLOG_ACTIVE_LEVEL in test. Should be SPDLOG_LEVEL_DEBUG"
+#endif
+
 TEST_CASE("debug and trace w/o format string", "[macros]]")
 {
+
     prepare_logdir();
     std::string filename = "logs/simple_log";
 
@@ -13,28 +18,24 @@ TEST_CASE("debug and trace w/o format string", "[macros]]")
     logger->set_pattern("%v");
     logger->set_level(spdlog::level::trace);
 
-    SPDLOG_TRACE(logger, "Test message 1");
-    SPDLOG_DEBUG(logger, "Test message 2");
+    SPDLOG_LOGGER_TRACE(logger, "Test message 1");
+    SPDLOG_LOGGER_DEBUG(logger, "Test message 2");
     logger->flush();
 
     REQUIRE(ends_with(file_contents(filename), "Test message 2\n"));
-    REQUIRE(count_lines(filename) == 2);
-}
+    REQUIRE(count_lines(filename) == 1);
 
-TEST_CASE("debug and trace with format strings", "[macros]]")
-{
-    prepare_logdir();
-    std::string filename = "logs/simple_log";
+    spdlog::set_default_logger(logger);
 
-    auto logger = spdlog::create<spdlog::sinks::basic_file_sink_mt>("logger", filename);
-    logger->set_pattern("%v");
-    logger->set_level(spdlog::level::trace);
-
-    SPDLOG_TRACE(logger, "Test message {}", 1);
-    // SPDLOG_DEBUG(logger, "Test message 2");
-    SPDLOG_DEBUG(logger, "Test message {}", 222);
+    SPDLOG_TRACE("Test message 3");
+    SPDLOG_DEBUG("Test message {}", 4);
     logger->flush();
 
-    REQUIRE(ends_with(file_contents(filename), "Test message 222\n"));
+    REQUIRE(ends_with(file_contents(filename), "Test message 4\n"));
     REQUIRE(count_lines(filename) == 2);
 }
+
+TEST_CASE("disable param evaluation", "[macros]")
+{
+    SPDLOG_TRACE("Test message {}", throw std::runtime_error("Should not be evaluated"));
+}
